<?php
/**
 * @brief		Background Task
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	(BIM) Topic Thumbnail
 * @since		15 May 2019
 */

namespace IPS\tthumb\extensions\core\Queue;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Background Task
 */
class _deleteTopicThumbnail
{
	/**
	 * @brief Number of topics to build per cycle
	 */
	public $rebuild = 50;
	
	/**
	 * Parse data before queuing
	 *
	 * @param	array	$data
	 * @return	array
	 */
	public function preQueueData( $data )
	{	
		$where[] = array( 'img_thumb!=?', 'no' );		
		try
		{		
			$data['count']		= \IPS\Db::i()->select( 'MAX(img_id)', 'tthumb_images', $where )->first();
			$data['realCount']	= \IPS\Db::i()->select( 'COUNT(*)', 'tthumb_images', $where)->first();
		}
		catch( \Exception $ex )
		{
			return NULL;
		}
		
		if( $data['count'] == 0 or $data['realCount'] == 0 )
		{
			return NULL;
		}

		$data['indexed'] = 0;
		
		return $data;
	}

	/**
	 * Run Background Task
	 *
	 * @param	mixed						$data	Data as it was passed to \IPS\Task::queue()
	 * @param	int							$offset	Offset
	 * @return	int							New offset
	 * @throws	\IPS\Task\Queue\OutOfRangeException	Indicates offset doesn't exist and thus task is complete
	 */
	public function run( $data, $offset )
	{
		$where[] = array( 'img_thumb!=?', 'no' );			
		$select = \IPS\Db::i()->select( '*', 'tthumb_images', $where, 'img_id', array( 0, $this->rebuild ) );

		foreach( $select as $row )
		{
			if ( $row['img_image'] )
			{
				try
				{
					\IPS\File::get( 'tthumb_Images', $row['img_image'] )->delete();
				}
				catch( \Exception $e ){}
			}
			if ( $row['img_thumb'] && $row['img_thumb'] != 'no' )
			{
				try
				{
					\IPS\File::get( 'tthumb_Images', $row['img_thumb'] )->delete();
				}
				catch( \Exception $e ){}
			}
			
			\IPS\Db::i()->update( 'tthumb_images', array(
				'img_image' => null,
				'img_thumb' => 'no' 
			), array( 'img_id=?', $row['img_id'] ) );			

			$data['indexed']++;
			$last = $row['img_id'];				
		}	
		
		# No last
		if( $last === NULL )
		{
			throw new \IPS\Task\Queue\OutOfRangeException;
		}
		
		# Done
		return $last;	
	}
	
	/**
	 * Get Progress
	 *
	 * @param	mixed					$data	Data as it was passed to \IPS\Task::queue()
	 * @param	int						$offset	Offset
	 * @return	array( 'text' => 'Doing something...', 'complete' => 50 )	Text explaining task and percentage complete
	 * @throws	\OutOfRangeException	Indicates offset doesn't exist and thus task is complete
	 */
	public function getProgress( $data, $offset )
	{
		return array( 'text' => \IPS\Member::loggedIn()->language()->addToStack('tthumb_deleting_task'), 'complete' => ( $data['realCount'] * $data['indexed'] ) > 0 ? round( ( $data['realCount'] * $data['indexed'] ) * 100, 2 ) : 0 );
	}

	/**
	 * Perform post-completion processing
	 *
	 * @param	array	$data
	 * @return	void
	 */
	public function postComplete( $data )
	{

	}
}