<?php
/**
 * @brief		Background Task
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	(BIM) Topic Thumbnail
 * @since		15 May 2019
 */

namespace IPS\tthumb\extensions\core\Queue;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Background Task
 */
class _rebuildTopicThumbnail
{
	/**
	 * @brief Number of topics to build per cycle
	 */
	public $perCycle = 20;
	
	/**
	 * Parse data before queuing
	 *
	 * @param	array	$data
	 * @return	array
	 */
	public function preQueueData( $data )
	{
		$data['where'] = NULL;
		
		$forumIds[] = 0;
		
		if ( \IPS\Settings::i()->tthumb_forum != "0" )
		{
			foreach( explode( ",", \IPS\Settings::i()->tthumb_forum ) as $f )
			{
				$forumIds[]	= $f;
			}
		}
		
		if ( \IPS\Settings::i()->tthumb_club == 1 )
		{
			foreach( \IPS\Db::i()->select( 'id', 'forums_forums', "club_id IS NOT NULL" ) as $c )
			{
				$forumIds[]	= $c;
			}
		}	
		
		if ( $forumIds && \count($forumIds) > 1 )
		{
			$forumIds = array_filter( $forumIds );
			$where[] = array( 'forum_id IN (' . implode(',', $forumIds) . ')' );		
			$data['where'] = $where;
		}
		
		try
		{			
			$data['count']	= \IPS\Db::i()->select( 'COUNT(*)', 'forums_topics', $where )->first();
		}
		catch( \Exception $ex )
		{
			throw new \OutOfRangeException;
		}
		
		if( $data['count'] == 0 )
		{
			return null;
		}
		
		return $data;
	}

	/**
	 * Run Background Task
	 *
	 * @param	mixed						$data	Data as it was passed to \IPS\Task::queue()
	 * @param	int							$offset	Offset
	 * @return	int							New offset
	 * @throws	\IPS\Task\Queue\OutOfRangeException	Indicates offset doesn't exist and thus task is complete
	 */
	public function run( $data, $offset )
	{

		$count = 0;
		
		foreach( \IPS\Db::i()->select( '*', 'forums_topics', $data['where'], 'tid DESC', array( $offset, $this->perCycle ) ) as $row )
		{
			$count++;
			
			try
			{
				$topic = \IPS\forums\Topic::constructFromData( $row );
			
				$tdata = $topic->tthumbGetData();
				
				if ( $tdata['img_image'] )
				{
					try
					{					
						$uploaded = \IPS\File::get( 'tthumb_Images', $tdata['img_image'] );
						$topic->createThumbnailFromUploadedImage( $uploaded );
						continue;
					}
					catch( \Exception $e ){}					
				}

				$getIMGs = $topic->tthumb_getIMGsInPost();
				
				if ( $getIMGs && \count($getIMGs) > 0 )
				{
					$topic->createThumbnailFromExternalUrl( $getIMGs[0] );
				}			
			}
			catch( \Exception $e ){}
		}
		
		if( !$count )
		{
			throw new \IPS\Task\Queue\OutOfRangeException;
		}

		return ( $offset + $count );			
	}
	
	/**
	 * Get Progress
	 *
	 * @param	mixed					$data	Data as it was passed to \IPS\Task::queue()
	 * @param	int						$offset	Offset
	 * @return	array( 'text' => 'Doing something...', 'complete' => 50 )	Text explaining task and percentage complete
	 * @throws	\OutOfRangeException	Indicates offset doesn't exist and thus task is complete
	 */
	public function getProgress( $data, $offset )
	{
		return array( 'text' => \IPS\Member::loggedIn()->language()->addToStack('tthumb_rebuilding_task'), 'complete' => round( 100 / $data['count'] * $offset, 2 ) );
	}

}