//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class tthumb_hook_forums_module_topic extends _HOOK_CLASS_
{
	/**
	 * View Topic
	 *
	 * @return    \IPS\Content\Item
	 * @throws \Exception
	 */
	public function execute()
	{
		try
		{
			try
			{
				parent::execute();
				
				try
				{
					$topic = \IPS\forums\Topic::load( \IPS\Request::i()->id );
					if ( $topic->container()->useOgImage() )
					{
						\IPS\Output::i()->metaTags["og:image"] = $topic->tthumb_show(1);
					}
				}
				catch ( \OutOfRangeException $e ){}		
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}
	
				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	
	/*-------------------------------------------------------------------------*/
	// Check permission
	/*-------------------------------------------------------------------------*/		
	private function loadTopicToChangeThumbnail($id)
	{
		try
		{
			try
			{
				# Load topic ID
				try
				{
					$class = static::$contentModel;
					$topic = $class::loadAndCheckPerms( $id );
				}
				catch ( \OutOfRangeException $e )
				{
					\IPS\Output::i()->json( array( 'type' => 'error', 'message' => \IPS\Member::loggedIn()->language()->get( 'tthumb_error_topicnotfound' ) ) );
					exit;
				}
		
				# Check all permission and return topic object
				if ( $topic->container()->canChangeThumb($topic->starter_id) )
				{	
					return $topic;
				}
				else
				{
					\IPS\Output::i()->json( array( 'type' => 'error', 'message' => \IPS\Member::loggedIn()->language()->get( 'tthumb_error_noperm' ) ) );
					exit;
				}
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}
	
				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	
	/*-------------------------------------------------------------------------*/
	// Change thumbnail - form
	/*-------------------------------------------------------------------------*/	
	public function changeTopicThumbnail()
    {	
		try
		{
			try
			{
				# Get topic
				$topic = $this->loadTopicToChangeThumbnail( \IPS\Request::i()->id );
		
				# Build form
				$form = new \IPS\Helpers\Form;
				$form->class = 'ipsForm_vertical';
				
				$options['fromTopic'] = 'tthumb_topic';
		
				if ( \IPS\Settings::i()->tthumb_postURL )
				{
					$options['fromURL'] = 'tthumb_fromURL';
				}
				
				$options['upload'] = 'tthumb_upload';
				$options['remove'] = 'tthumb_remove';			
				$toggles = array( 'upload' => array( 'tthumb_upload' ), 'fromURL' => array( 'tthumb_fromURL' ), 'fromTopic' => array('tthumb_topic') );
				$form->add( new \IPS\Helpers\Form\Select( 'tthumb_type', 'fromTopic', FALSE, array( 'options' => $options, 'toggles' => $toggles ) ) );
		
				if ( \IPS\Settings::i()->tthumb_postURL )
				{
					$form->add( new \IPS\Helpers\Form\Text( 'tthumb_fromURL', NULL, FALSE, array(), NULL, NULL, NULL, 'tthumb_fromURL' ) );
				}
				$form->add( new \IPS\Helpers\Form\Upload( 'tthumb_upload', NULL, FALSE, array(
					'image' 			=> array( 'maxWidth' => 600, 'maxHeight' => 600 ), 
					'storageExtension' 	=> 'tthumb_Images', 
					'maxFileSize' 		=> \IPS\Settings::i()->tthumb_max_upload > 0 ? \IPS\Settings::i()->tthumb_max_upload : 2, 
					'template' 			=> 'forums.upload.topicthumbnail',
				), NULL, NULL, NULL, 'tthumb_upload' ) );
				$form->add( new \IPS\Helpers\Form\Custom( 'tthumb_imgfromtopic', NULL, FALSE, array( 'getHtml' => function( $element ) use ( $topic )
				{
					$imgs = $topic->tthumb_getIMGsInPost();
					return \IPS\Theme::i()->getTemplate( 'view', 'tthumb', 'front' )->tthumb_listIMG( $imgs );
				} ), NULL, NULL, NULL, 'tthumb_topic' ) );
				
				$isWidget = \IPS\Request::i()->widget == 1 ? true : false;
				
				/* Display */
				$html = \IPS\Theme::i()->getTemplate( 'view', 'tthumb', 'front' )->tthumb_changeThumb( $topic, $imgs, $form, $isWidget );
				
				if( \IPS\Request::i()->isAjax() )
				{
					\IPS\Output::i()->sendOutput( $html, 200, 'text/html', \IPS\Output::i()->httpHeaders );
				}
				else
				{
					\IPS\Output::i()->output = $html;
					\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack( 'tthumb_changeThumb' );
					\IPS\Output::i()->breadcrumb[] = array( NULL, \IPS\Member::loggedIn()->language()->addToStack( 'tthumb_changeThumb' ) );	
				}	
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}
	
				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
		
	/*-------------------------------------------------------------------------*/
	// Save
	/*-------------------------------------------------------------------------*/	
	public function saveThumb()
    {
	try
	{
		try
		{
				\IPS\Session::i()->csrfCheck();
				
				# Get topic
				$topic = $this->loadTopicToChangeThumbnail( \IPS\Request::i()->id );
				
				switch( \IPS\Request::i()->getfrom )
				{
					case 'fromURL':
						$thumbnail = \IPS\Request::i()->thumbURL;
					break;
					case 'upload':
						$thumbnail = \IPS\File::get( 'tthumb_Images', \IPS\Request::i()->thumbURL );
					break;
					case 'fromTopic':		
						$thumbnail = $topic->tthumbGetRealIMG( \IPS\Request::i()->thumbURL );
					break;
					case 'remove':
						$thumbnail = \IPS\Settings::i()->tthumb_defaultimg ? \IPS\File::get( 'core_Theme', \IPS\Settings::i()->tthumb_defaultimg )->url : \IPS\Theme::i()->resource( 'noThumb.png', 'tthumb', 'front' );
					break;		
				}		
				
				
				if ( ! $thumbnail )
				{
					\IPS\Output::i()->json( array( 'type' => 'error', 'message' => \IPS\Member::loggedIn()->language()->get( 'tthumb_error_noURL' ) ) );
					exit;
				}
				
				# Update topic thumbnail database
				if ( \IPS\Request::i()->getfrom == 'remove' )
				{
					$topic->tthumbDelete();
					
					\IPS\Db::i()->update( 'tthumb_images', array(
						'img_image' => null,
						'img_thumb' => 'no' 
					), array( 'img_topic_id=?', $topic->tid ) );				
				}
				elseif ( \IPS\Request::i()->getfrom == 'upload' )
				{
					if ( $topic->upload_thumbnail != (string) $thumbnail )
					{
						$topic->createThumbnailFromUploadedImage( $thumbnail );
					}
				}
				else
				{
					$topic->createThumbnailFromExternalUrl( $thumbnail );
				}
				
				# Delete widget cache
				if ( \IPS\Request::i()->clearCache == 1 )
				{
					\IPS\Widget::deleteCaches();
				}
				
				# Ouput
				if ( \IPS\Request::i()->isAjax() )
				{
					$newThumb = \IPS\Request::i()->getfrom == 'upload' ? \IPS\Request::i()->thumbURL : $thumbnail;
					\IPS\Output::i()->json( array( 'newThumb' => $newThumb, 'type' => 'OK', 'message' => \IPS\Member::loggedIn()->language()->get( 'tthumb_msg_saved' )) );
				}
				else
				{
					\IPS\Output::i()->redirect( isset( $_SERVER['HTTP_REFERER'] ) ? $_SERVER['HTTP_REFERER'] : \IPS\Http\Url::internal( '' ) );
				}
				}
				catch ( \Error | \RuntimeException $e )
				{
					if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
					{
						\IPS\Log::log( $e, 'hook_exception' );
					}
	
					if ( method_exists( get_parent_class(), __FUNCTION__ ) )
					{
						return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
					}
					else
					{
						throw $e;
					}
				}
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}

				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
	}	

	/*-------------------------------------------------------------------------*/
	// Get original image for preview
	/*-------------------------------------------------------------------------*/	
	protected function tthumbGetImage()
	{
		try
		{
			try
			{
				try
				{
					$class = static::$contentModel;
					$topic = $class::loadAndCheckPerms( \IPS\Request::i()->id );
				}
				catch ( \OutOfRangeException $e )
				{
					\IPS\Output::i()->json( array( 'type' => 'error', 'message' => \IPS\Member::loggedIn()->language()->get( 'tthumb_error_topicnotfound' ) ) );
					exit;
				}
						
				$thumb = (string) $topic->tthumb_show(1);
				$html = "<img src='{$thumb}' class='tthumbPreviewIMG'>";
				\IPS\Output::i()->sendOutput( $html );
				return;		
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}
	
				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

}
