<?php
/**
 * @brief		tthumbWidget Widget
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	tthumb
 * @since		18 Jan 2019
 */

namespace IPS\tthumb\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * tthumbWidget Widget
 */
class _tthumbWidget extends \IPS\Content\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'tthumbWidget';
	
	/**
	 * @brief	App
	 */
	public $app = 'tthumb';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
	
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
		if ( $this->configuration['tthumb_style'] == '_0' )
		{
			\IPS\Output::i()->endBodyCode .= "<script>$(function($) { if ( $('.ipsWidget_horizontal .tthumb_Widget .tthumb_gal_wrap').length ) { $('.tthumb_gal_wrap').imagesLoaded( function (images) { $('.tthumb_gal_wrap').masonry(); }); }});	</script>";
		}
		$this->template( array( \IPS\Theme::i()->getTemplate( 'view', 'tthumb', 'front' ), 'tthumb_widget' ) );
		parent::init();
	}
	
	/**
	 * Class
	 */
	protected static $class = 'IPS\forums\Topic';

	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
 		$form = parent::configuration( $form );

		if ( \IPS\Dispatcher::i()->controllerLocation != 'admin' )
		{		
			$form->elements[""]['widget_feed_container_topic'] = null;

			$form->elements[""]['widget_feed_container_topic'] = new \IPS\Helpers\Form\Node( 'widget_feed_container_topic', isset( $this->configuration['widget_feed_container'] ) ? $this->configuration['widget_feed_container'] : 0, FALSE, array(
				'class'           => '\IPS\forums\Forum',
				'zeroVal'         => 'all',
				'permissionCheck' => 'view',
				'multiple'        => true,
				'forceOwner'	  => false,
				'clubs'			  => true,
			) );
		}
		
		$form->add( new \IPS\Helpers\Form\Select( 'tthumb_style', $this->configuration['tthumb_style'] ? $this->configuration['tthumb_style'] : '_1', FALSE, array(
            'options' => array(
				'_0'		=> 'tthumb_masonry',			
	            '_1'    	=> 'tthumb_gridview',
	            '_2'    	=> 'tthumb_standard',
            )
        ) ) );		
		
		return $form;
 	} 
	
	/**
	 * Get where clause
	 *
	 * @return	array
	 */
	protected function buildWhere()
	{
		$where = parent::buildWhere();
		if ( !isset( $this->configuration['widget_feed_use_perms'] ) or $this->configuration['widget_feed_use_perms'] )
		{
			$where['container'][] = array( 'forums_forums.password IS NULL AND forums_forums.can_view_others=1' );
		}
		return $where;
	}
	
	/**
	 * Get HTML using the template (language strings not parsed)
	 *
	 * @return	string
	 */	
	public function output()
	{
		$args = \func_get_args();
		$args['conf'] = $this->configuration;
		$args['orientation'] = $this->orientation;

		$output = \call_user_func_array( $this->template, $args );

		return $output;
	}	
}